function z = fcn_alss(y, w_a, lambda, p)
% Author:           Benjamin Schuler
% Company:          University of Stuttgart, Institute for System Dynamics
% Last modified:    11.02.2019 (Matlab 2015a)
%
% Estimate baseline with asymmetric least squares method
% Adapted version with weight vector w_a
%
% y         ... sampled data points
% w_a       ... adapted weight vector
% p         ... weight for asymmetry    (0 < p < 1)
% lambda    ... weight for smoothness   (10^-5 < lambda < 10^5)
%
% References:
%   Paul H. C. Eilers, Hans F. M. Boelens, Baseline Correction with
%       Asymmetric Least Squares Smoothing, 2005
%
%   Lucca Khner, Surface-enhanced spectroscopy of glucose, 2018, 
%       University of Stuttgart, 4th Physics Institute, Master Thesis

m = length(y);              % number of samples
D = diff(speye(m),2);       
w = w_a; %ones(m,1);        % replace (initial) w by input weight vector w_a

% figure;
for ii = 1:2
    W = spdiags(w,0,m,m);
    C = chol(W + lambda*(D'*D));
    z = C\(C'\(w.*y));
    w = w_a.*(p*(y>z) + (1-p)*(y<z)); % multiply with w_a -> only changes in weights for not 'kicked-out' datapoints
%     plot(w,'x'); hold all
end