%% Generate figure 5 - rel. refl. of bc-signals for gc & fc
%
% Author:           Benjamin Schuler
% Company:          University of Stuttgart, Institute for System Dynamics
% Last modified:    21.02.2019 (Matlab 2015a)

clear; close all; clc;
cfroot = cd;

%% settings

% window for wavenumbers
bWindowOn = true;       % enable window for exclusion
w_exc_LB = 1000;        % lower bound for exclusion from ALSS
w_exc_UB = 1100;        % upper bound for exclusion from ALSS
waveband = 3;           % band of wavenumbers around characteristic wavenumbers nu_i
w_LB = 800;             % lower bound of wavenumber-sepctrum for plot
w_UB = 2500;            % upper bound of wavenumber-sepctrum for plot

% parameters for Asymmetric Least Squares Smoothing (ALSS)
lambda = 500;
p      = 0.99;

% characteristic wavenumbers
wn1 = 1034;    % [1/cm]    % 1. characteristic wavenumber of glucose
wn2 = 1063;    % [1/cm]    % 1. characteristic wavenumber of fructose
wn3 = 1078;    % [1/cm]    % 2. characteristic wavenumber of glucose/fructose

% load plot style
load('plotstyleBS.mat')
mgrCD = (lgrCD+dgrCD)/2;    % additional color
clr1 = [repmat(mgrCD,6,1); lg; lg;...
       0.5*(lg+dg); 0.5*(lg+dg); dg]; % color vector
clr2 = [repmat(mgrCD,6,1); lbCD; lbCD;...
       0.5*(lbCD+dbCD); 0.5*(lbCD+dbCD); dbCD]; % color vector
clr3 = [repmat(mgrCD,6,1);...
        lg; 1/3*lg+2/3*lbCD; lbCD; 2/3*lg+1/3*lbCD; (lg+lbCD)/2]; % color vector
fs = 14; % font size
fs_legend = 13; % font size in legend

%% load data
% idxCycle = 1 ... glucose cycle
% idxCycle = 2 ... fructose cycle
% idxCycle = 3 ... mixed cycle

% initialize figure
hf = figure('color','white','visible','off');

for idxCycle=1:3
    
    switch idxCycle
        case 1; hs1 = subplot(1,3,idxCycle);
        case 2; hs2 = subplot(1,3,idxCycle);
        case 3; hs3 = subplot(1,3,idxCycle);
    end
    hp = plot(NaN,NaN); hp = repmat(hp,11,1);
    if bWindowOn==true
    	ymin = 0.925; ymax = 1.175;
    else
        ymin = 0.99; ymax = 1.04;
    end
    vert = [wn1-waveband ymin; wn1+waveband ymin;
            wn1+waveband ymax; wn1-waveband ymax;
            wn2-waveband ymin; wn2+waveband ymin;
            wn2+waveband ymax; wn2-waveband ymax
            wn3-waveband ymin; wn3+waveband ymin;
            wn3+waveband ymax; wn3-waveband ymax];
    fac1 = [1 2 3 4]; fclr1 = lg;
    fac2 = [5 6 7 8]; fclr2 = lbCD;
    fac3 = [9 10 11 12]; fclr3 = (lg+lbCD)/2;
    hb1 = patch('Faces',fac1,'Vertices',vert,'FaceColor',fclr1,'FaceAlpha',0.4,'EdgeColor','none'); hold on;
    hb2 = patch('Faces',fac2,'Vertices',vert,'FaceColor',fclr2,'FaceAlpha',0.4,'EdgeColor','none');
    hb3 = patch('Faces',fac3,'Vertices',vert,'FaceColor',fclr3,'FaceAlpha',0.4,'EdgeColor','none');
        
    switch idxCycle
        case 1;
            matFile = 'gc_data.mat';
            datasets = {'gc_1_c10_gl';'gc_1_water';...
                        'gc_2_c25_gl';'gc_2_water';...
                        'gc_3_c50_gl';'gc_3_water';...
                        'gc_4_c25_gl';'gc_4_water';...
                        'gc_5_c10_gl';'gc_5_water';...
                        'gc_6_water'};
        case 2;
            matFile = 'fc_data.mat';
            datasets = {'fc_1_c10_gl';'fc_1_water';...
                        'fc_2_c25_gl';'fc_2_water';...
                        'fc_3_c50_gl';'fc_3_water';...
                        'fc_4_c25_gl';'fc_4_water';...
                        'fc_5_c10_gl';'fc_5_water';...
                        'fc_6_water'};
        case 3;
            matFile = 'mc_data.mat';
            datasets = {'mc_1_G50_F0';'mc_1_water';...
                        'mc_2_F50_G0';'mc_2_water';...
                        'mc_3_F50_G50';'mc_3_water';...
                        'mc_4_30F_60G';'mc_4_water';...
                        'mc_5_F60_G30';'mc_5_water';...
                        'mc_6_water'};
    end
    load(matFile);

    counter_clr = 0;
    for idxSet=[2,4,6,8,10,11,1,9,3,7,5]
        
        counter_clr = counter_clr+1;

        % data set
        dataset = datasets{idxSet};
        eval(['x =',dataset,'.data1;']) 
        eval(['y =',dataset,'.data2;']) 

        % convert cell to array
        n = length(x{1});               % number of measurements
        m = length(x);                  % number of sampled data points
        x = reshape(cell2mat(x),n,m);   % wavenumbers [cm-1]
        y = reshape(cell2mat(y),n,m);   % rel. reflectance
    
        % mean value
        xc = mean(x,2);
        yc = mean(y,2);
       
        % apply ALSS
        w_a = ones(size(xc));
        if bWindowOn==true
            idxLB = find(xc>w_exc_LB,1,'first');
            idxUB = find(xc>w_exc_UB,1,'first');
            w_a(idxLB:idxUB) = zeros(idxUB-idxLB+1,1);
        end
        zc    = cell(length(lambda),length(p));
        zc_bc = cell(length(lambda),length(p));
        for idxL=1:length(lambda)
            for idxP=1:length(p)
                zc{idxL,idxP}    = fcn_alss(yc,w_a,lambda(idxL),p(idxP));
                zc_bc{idxL,idxP} = yc./zc{idxL,idxP};
            end
        end
        
        % extract height of peak at characteristic wavenumbers
        [~,idx1] = min((xc-wn1).^2);
        [~,idx2] = min((xc-wn2).^2);
        [~,idx3] = min((xc-wn3).^2);
        s1 = zeros(length(lambda),1);
        s2 = s1; s3 = s1;
        for idxL=1:length(lambda)
            for idxP=1:length(p)
                s1(idxL,idxP) = (1-min(zc_bc{idxL,idxP}((idx1-waveband):(idx1+waveband))))*100;
                s2(idxL,idxP) = (1-min(zc_bc{idxL,idxP}((idx2-waveband):(idx2+waveband))))*100;
                s3(idxL,idxP) = (1-min(zc_bc{idxL,idxP}((idx3-waveband):(idx3+waveband))))*100;
            end
        end
              
        % plot
        idx_wLB = find(xc>=1000,1,'first');     % index LB
        idx_wUB = find(xc>=1100,1,'first')-1;   % index UB
        for idxL=1:length(lambda)
            for idxP=1:length(p)
                hold on;
                switch idxCycle
                    case 1; hp(counter_clr) = plot(xc,zc_bc{idxL,idxP},cls,clr1(counter_clr,:),lws,lw);
                    case 2; hp(counter_clr) = plot(xc,zc_bc{idxL,idxP},cls,clr2(counter_clr,:),lws,lw);
                    case 3; hp(counter_clr) = plot(xc,zc_bc{idxL,idxP},cls,clr3(counter_clr,:),lws,lw);
                end
            end
        end
    end
    
    % additional settings for figure
    xlabel('\nu [cm^{-1}]')
    
    ylim([ymin ymax]);
    xlim([1000 1100]);
    set(gca,'XTick',[1000 1025 1050 1075 1100]);
    set(gca,'XTickLabel',{'1000','1025','1050','1075','1100'});
    if bWindowOn==true
        set(gca,'YTick',[0.925 0.95 0.975 1 1.025 1.05 1.075 1.10 1.125 1.15 1.175]);% 1.10 1.15 1.20]);
        set(gca,'YTickLabel',{'','0.95','','1.00','','1.05','','1.10','','1.15',''});%,'','',''});
    else
        set(gca,'YTick',[0.99 1 1.01 1.02 1.03 1.04]);
        set(gca,'YTickLabel',{'0.99','1.00','1.01','1.02','1.03','1.04'});
    end
    grid on; box on;
    locationstr = 'northeast';%'northoutside';
    if idxCycle==1
        title('(a)');
        ylabel('r_{BC}(\nu)');
        hl1 = legend([hp(1), hp(7), hp(9), hp(11)],...
           {'water','c_{glucose} = 10 g/l','c_{glucose} = 25 g/l','c_{glucose} = 50 g/l'},...
           'location',locationstr,fss,fs_legend,...
           'orientation','vertical');
    elseif idxCycle==2
        title('(b)');
        ylabel(' ');
        set(gca,'YTickLabel',{});
        hl2 = legend([hp(1), hp(7), hp(9), hp(11)],...
               {'water','c_{fructose} = 10 g/l','c_{fructose} = 25 g/l','c_{fructose} = 50 g/l'},...
               'location',locationstr,fss,fs_legend);
    else
        title('(c)');
        ylabel(' ');
%         ylabel('r_{BC}(\nu)');
%         set(gca,'YAxisLocation','right');
        set(gca,'YTickLabel',{});
        hl3 = legend([hp(7), hp(9), hp(11), hp(10), hp(8)],...
               {'c_g:c_f = 50:0 g/l',...
                'c_g:c_f = 0:50 g/l',...
                'c_g:c_f = 50:50 g/l',...
                'c_g:c_f = 60:30 g/l',...
                'c_g:c_f = 30:60 g/l'},...
                'location',locationstr,fss,fs_legend);
    end
end

set(hs1,'OuterPosition',[0, 0, 1/3, 1]);
set(hs2,'OuterPosition',[1/3, 0, 1/3, 1]);
set(hs3,'OuterPosition',[2/3, 0, 1/3, 1]);

% adjust font size
set(findobj(gcf,fss,10),fss,fs)

% export figure
cd('..\02_Graphics')
orient(hf,'landscape')
set(hf,'PaperSize',[29.7 21*0.5])
set(hf,'PaperPosition',[0 0 29.7 21*0.5])
set(hf,'Renderer','painters')
if bWindowOn==true
    print(hf,'figure_5_paper','-djpeg','-r300');
    print(hf,'figure_5_paper','-dpdf', '-r300');
else
    print(hf,'figure_5_nw','-djpeg','-r300');
end
cd(cfroot)