%% Conversion of measurement data
%  *.txt to *.mat
%
% Author:           Benjamin Schuler
% Company:          University of Stuttgart, Institute for System Dynamics
% Last modified:    21.02.2019 (Matlab 2015a)

clear; close all; clc;
cfroot = cd;

%% load txt-files

cycle  = {'Fructose cycles';... % = fc
          'Glucose cycles';...  % = gc
          'Mixed cycles'};      % = mc

% ii ... index of measurement cycle (fructose / glucose / mixed)
% jj ... index of measurement set   ( water / 10gl / 25gl / 50gl)
% kk ... index of measurement       (0...29)

% Switch to folder
cd('..\00_Measurement_Data\'); cf = cd;

for ii=1:length(cycle)
    folder_ii = [cf,'\',cycle{ii},'\'];
    cd(folder_ii);
    measurement_sets_ii = cellstr(ls);
    switch ii
        case 1; prefix = 'fc';
        case 2; prefix = 'gc';
        case 3; prefix = 'mc';
    end
    for jj=3:length(measurement_sets_ii)
        cd([folder_ii,'\',measurement_sets_ii{jj}])
        list2 = cellstr(ls);
        cd([folder_ii,'\',measurement_sets_ii{jj},'\',list2{3},'\'])
        txt_files_ii_jj = cellstr(ls);

        data1 = cell(length(txt_files_ii_jj)-2,1);
        data2 = cell(length(txt_files_ii_jj)-2,1);

        for kk=3:length(txt_files_ii_jj)
            fileName = regexp(txt_files_ii_jj{kk},'\.','split');
            nr = str2double(fileName{2})+1;
            data_txt = dlmread(txt_files_ii_jj{kk});

            data1{nr} = data_txt(:,1);
            data2{nr} = data_txt(:,2);
        end
        
        varName = [prefix,'_',regexprep(regexprep(measurement_sets_ii{jj},'\ ','_'),'\=','')];
        eval([varName,'.data1 = data1;'])
        eval([varName,'.data2 = data2;'])    
        
        cd('..\')
        cd('..\')
    end
end
cd(cfroot)

%% tidy up workspace
clear cf cycle data1 data2 data_txt fileName folder_ii ii jj kk
clear list2 measurement_sets_ii nr prefix txt_files_ii_jj varName

%% save to mat-file
save('fc_data.mat','-regexp','^fc')
save('gc_data.mat','-regexp','^gc')
save('mc_data.mat','-regexp','^mc')
