%% Estimate concentrations
% Results are saved to results_polyfit.xlsx
%
% Author:           Benjamin Schuler
% Company:          University of Stuttgart, Institute for System Dynamics
% Last modified:    21.02.2019 (Matlab 2015a)

clear; close all; clc;
cfroot = cd;

%% settings

% characteristic wavenumbers
wn1 = 1034;    % [1/cm]    % 1. characteristic wavenumber of glucose
wn2 = 1063;    % [1/cm]    % 1. characteristic wavenumber of fructose
wn3 = 1078;    % [1/cm]    % 2. characteristic wavenumber of glucose/fructose  

% options for fitting of basic functions
addzeros = 10;  % weighting for origin

% results
bWindowOn = true;
bPlot = true;

% load plot style
load('plotstyleBS.mat')
fs = 14; % font size
fs_legend = 13; % font size in legend
mbCD = (lbCD+dbCD)/2;   % additional color
visibility = 'off';
ds_lbl = {'1034','1063','1078'};

%% import results from excel sheet
file  = 'results_alss_bc.xlsx';
if bWindowOn==true
    sheet = 'results_pp';
else
    sheet = 'results_pp_nw';
end

ds1034.gc = xlsread(file,sheet,'D2:D12');
ds1034.fc = xlsread(file,sheet,'D13:D23');
ds1034.mc = xlsread(file,sheet,'D24:D34');
ds1063.gc = xlsread(file,sheet,'E2:E12');
ds1063.fc = xlsread(file,sheet,'E13:E23');
ds1063.mc = xlsread(file,sheet,'E24:E34');
ds1078.gc = xlsread(file,sheet,'F2:F12');
ds1078.fc = xlsread(file,sheet,'F13:F23');
ds1078.mc = xlsread(file,sheet,'F24:F34');

idxSort = [2,1,4,3,6,5,8,7,10,9,11];
ds1034.gc = ds1034.gc(idxSort);
ds1034.fc = ds1034.fc(idxSort);
ds1034.mc = ds1034.mc(idxSort);
ds1063.gc = ds1063.gc(idxSort);
ds1063.fc = ds1063.fc(idxSort);
ds1063.mc = ds1063.mc(idxSort);
ds1078.gc = ds1078.gc(idxSort);
ds1078.fc = ds1078.fc(idxSort);
ds1078.mc = ds1078.mc(idxSort);

%% evaluation

% pure water
idx_w = 1:2:11;
ds1034_w_gc = mean(ds1034.gc(idx_w,1));
ds1034_w_fc = mean(ds1034.fc(idx_w,1));
ds1034_w_mc = mean(ds1034.mc(idx_w,1));
ds1034_w_k = mean([ds1034_w_gc, ds1034_w_fc, ds1034_w_mc]);
ds1063_w_gc = mean(ds1063.gc(idx_w,1));
ds1063_w_fc = mean(ds1063.fc(idx_w,1));
ds1063_w_mc = mean(ds1063.mc(idx_w,1));
ds1063_w_k = mean([ds1063_w_gc, ds1063_w_fc, ds1063_w_mc]);
ds1078_w_gc = mean(ds1078.gc(idx_w,1));
ds1078_w_fc = mean(ds1078.fc(idx_w,1));
ds1078_w_mc = mean(ds1078.mc(idx_w,1));
ds1078_w_k = mean([ds1078_w_gc, ds1078_w_fc, ds1078_w_mc]);
ds1034_w = [(ds1034.gc(idx_w,1)-ds1034_w_gc);...
            (ds1034.fc(idx_w,1)-ds1034_w_fc);...
            (ds1034.mc(idx_w,1)-ds1034_w_mc)];
ds1063_w = [(ds1063.gc(idx_w,1)-ds1063_w_gc);...
            (ds1063.fc(idx_w,1)-ds1063_w_fc);...
            (ds1063.mc(idx_w,1)-ds1063_w_mc)];
ds1078_w = [(ds1078.gc(idx_w,1)-ds1078_w_gc);...
            (ds1078.fc(idx_w,1)-ds1078_w_fc);...
            (ds1078.mc(idx_w,1)-ds1078_w_mc)];
bPlotWater=true;

% nFit_g ... polynomial order for glucose
% nFit_f ... polynomial order for fructose
err_rms = zeros(3,3);
err_avg = zeros(3,3);
err_max = zeros(3,3);

for nFit_g = 1:3
    for nFit_f = 1:3

        % pure glucose (with subtractet water)
        idx_c = [10,10,25,25,50,50]';
        ds1034_g = [ds1034.gc(2)-ds1034_w_gc;...
                    ds1034.gc(10)-ds1034_w_gc;...
                    ds1034.gc(4)-ds1034_w_gc;...
                    ds1034.gc(8)-ds1034_w_gc;...
                    ds1034.gc(6)-ds1034_w_gc;...
                    ds1034.mc(2)-ds1034_w_mc;...
                    ];
        ds1063_g = [ds1063.gc(2)-ds1063_w_gc;...
                    ds1063.gc(10)-ds1063_w_gc;...
                    ds1063.gc(4)-ds1063_w_gc;...
                    ds1063.gc(8)-ds1063_w_gc;...
                    ds1063.gc(6)-ds1063_w_gc;...
                    ds1063.mc(2)-ds1063_w_mc;...
                    ];
        ds1078_g = [ds1078.gc(2)-ds1078_w_gc;...
                    ds1078.gc(10)-ds1078_w_gc;...
                    ds1078.gc(4)-ds1078_w_gc;...
                    ds1078.gc(8)-ds1078_w_gc;...
                    ds1078.gc(6)-ds1078_w_gc;...
                    ds1078.mc(2)-ds1078_w_mc;...
                    ];
        coeff_ds1034_g_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1034_g;zeros(addzeros,1)],nFit_g);
        ds1034_g_fit       = polyval(coeff_ds1034_g_fit,0:50);
        coeff_ds1063_g_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1063_g;zeros(addzeros,1)],nFit_g);
        ds1063_g_fit       = polyval(coeff_ds1063_g_fit,0:50);
        coeff_ds1078_g_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1078_g;zeros(addzeros,1)],nFit_g);
        ds1078_g_fit       = polyval(coeff_ds1078_g_fit,0:50);

        % pure glucose (with subtractet water)
        ds1034_f = [ds1034.fc(2)-ds1034_w_fc;...
                    ds1034.fc(10)-ds1034_w_fc;...
                    ds1034.fc(4)-ds1034_w_fc;...
                    ds1034.fc(8)-ds1034_w_fc;...
                    ds1034.fc(6)-ds1034_w_fc;...
                    ds1034.mc(4)-ds1034_w_mc;...
                    ];
        ds1063_f = [ds1063.fc(2)-ds1063_w_fc;...
                    ds1063.fc(10)-ds1063_w_fc;...
                    ds1063.fc(4)-ds1063_w_fc;...
                    ds1063.fc(8)-ds1063_w_fc;...
                    ds1063.fc(6)-ds1063_w_fc;...
                    ds1063.mc(4)-ds1063_w_mc;...
                    ];
        ds1078_f = [ds1078.fc(2)-ds1078_w_fc;...
                    ds1078.fc(10)-ds1078_w_fc;...
                    ds1078.fc(4)-ds1078_w_fc;...
                    ds1078.fc(8)-ds1078_w_fc;...
                    ds1078.fc(6)-ds1078_w_fc;...
                    ds1078.mc(4)-ds1078_w_mc;...
                    ];
        coeff_ds1034_f_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1034_f;zeros(addzeros,1)],nFit_f);
        ds1034_f_fit       = polyval(coeff_ds1034_f_fit,0:50);
        coeff_ds1063_f_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1063_f;zeros(addzeros,1)],nFit_f);
        ds1063_f_fit       = polyval(coeff_ds1063_f_fit,0:50);
        coeff_ds1078_f_fit = polyfit([idx_c;zeros(addzeros,1)],[ds1078_f;zeros(addzeros,1)],nFit_f);
        ds1078_f_fit       = polyval(coeff_ds1078_f_fit,0:50);
        
        % reconstruction of concentrations
        x0 = [0;0];
        options = optimset('Algorithm',{'levenberg-marquardt',0.005},...
                           'Display', 'off',...% 'iter' / 'off'
                           'TolFun', 1e-12,...
                           'TolX', 1e-12,...
                           'MaxIter', 1e8,...
                           'MaxFunEvals',1e8);%'PlotFcns', {  @optimplotx @optimplotfval });
        param.nFit_g = nFit_g;
        param.nFit_f = nFit_f;
        switch nFit_g
            case 1;
                param.a = [0, 0, coeff_ds1034_g_fit];
                param.b = [0, 0, coeff_ds1063_g_fit];
                param.c = [0, 0, coeff_ds1078_g_fit];
            case 2;
                param.a = [0, coeff_ds1034_g_fit];
                param.b = [0, coeff_ds1063_g_fit];
                param.c = [0, coeff_ds1078_g_fit];
            case 3;
                param.a = coeff_ds1034_g_fit;
                param.b = coeff_ds1063_g_fit;
                param.c = coeff_ds1078_g_fit;
            otherwise
                warndlg('polynomial order to high. please choose between 1 and 3.')
        end
        switch nFit_f
            case 1;
                param.d = [0, 0, coeff_ds1034_f_fit];
                param.e = [0, 0, coeff_ds1063_f_fit];
                param.f = [0, 0, coeff_ds1078_f_fit];
            case 2;
                param.d = [0, coeff_ds1034_f_fit];
                param.e = [0, coeff_ds1063_f_fit];
                param.f = [0, coeff_ds1078_f_fit];
            case 3;
                param.d = coeff_ds1034_f_fit;
                param.e = coeff_ds1063_f_fit;
                param.f = coeff_ds1078_f_fit;
            otherwise
                warndlg('polynomial order to high. please choose between 1 and 3.')
        end

        % initialize concentration
        cg_g = zeros(11,1);
        cf_g = zeros(11,1);
        cg_f = zeros(11,1);
        cf_f = zeros(11,1);
        cg_m = zeros(11,1);
        cf_m = zeros(11,1);

        % glucose cycle
        ds_g = [(ds1034.gc-ds1034_w_gc)';
                (ds1063.gc-ds1063_w_gc)';
                (ds1078.gc-ds1078_w_gc)'];
        for ii=1:length(cg_g)
            param.ds = ds_g(:,ii);
            [xOpt,fval,exitflag,output] = fsolve(@(x)fcn_polyfit(x,param),x0,options);
            cg_g(ii,1) = xOpt(1);
            cf_g(ii,1) = xOpt(2);
        end

        % fructose cycle
        ds_f = [(ds1034.fc-ds1034_w_fc)';
                (ds1063.fc-ds1063_w_fc)';
                (ds1078.fc-ds1078_w_fc)'];
        for ii=1:length(cg_f)
            param.ds = ds_f(:,ii);
            [xOpt,fval,exitflag,output] = fsolve(@(x)fcn_polyfit(x,param),x0,options);
            cg_f(ii,1) = xOpt(1);
            cf_f(ii,1) = xOpt(2);
        end

        % mixed cycle
        ds_m = [(ds1034.mc-ds1034_w_mc)';
                (ds1063.mc-ds1063_w_mc)';
                (ds1078.mc-ds1078_w_mc)'];
        for ii=1:length(cg_m)
            param.ds = ds_m(:,ii);
            [xOpt,fval,exitflag,output] = fsolve(@(x)fcn_polyfit(x,param),x0,options);
            cg_m(ii,1) = xOpt(1);
            cf_m(ii,1) = xOpt(2);
        end

        % set all negative concentrations to zero
        cg_g(find(cg_g<0)) = zeros(size(find(cg_g<0)));
        cf_g(find(cf_g<0)) = zeros(size(find(cf_g<0)));
        cg_f(find(cg_f<0)) = zeros(size(find(cg_f<0)));
        cf_f(find(cf_f<0)) = zeros(size(find(cf_f<0)));
        cg_m(find(cg_m<0)) = zeros(size(find(cg_m<0)));
        cf_m(find(cf_m<0)) = zeros(size(find(cf_m<0)));
        
        % evaluate results
        cg_gd = [0,10,0,25,0,50,0,25,0,10,0]';
        cf_gd = zeros(11,1);
        cg_fd = zeros(11,1);
        cf_fd = [0,10,0,25,0,50,0,25,0,10,0]';
        cg_md = [0,50,0, 0,0,50,0,60,0,30,0]';
        cf_md = [0, 0,0,50,0,50,0,30,0,60,0]';

        setvalue_vec = [cg_gd; cf_gd; cg_fd; cf_fd; cg_md; cf_md];
        isvalue_vec  = [cg_g;  cf_g;  cg_f;  cf_f;  cg_m;  cf_m];
        err_rms(nFit_g,nFit_f) = rms(setvalue_vec-isvalue_vec);
        err_avg(nFit_g,nFit_f) = mean(abs(setvalue_vec-isvalue_vec));
        err_max(nFit_g,nFit_f) = max(abs(setvalue_vec-isvalue_vec));

        %% visualization
        
        if bPlot==true
            if bPlotWater==true
                % analyzation of water
                hf = figure('color','white','visible',visibility);
                locationstr = 'northeast';
                subplot 131
                hpw11 = plot(idx_w,ds1034.gc(idx_w),cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
                hpw12 = plot(idx_w,ds1034.fc(idx_w),cls,dbCD,lws,lw,lss,'none','Marker','d',mss,11);
                hpw13 = plot(idx_w,ds1034.mc(idx_w),cls,mbCD,lws,lw,lss,'none','Marker','o',mss,11);
                hpw11m = plot(1:11,ds1034_w_gc*ones(1,11),cls,lbCD,lws,lw,lss,'--');
                hpw12m = plot(1:11,ds1034_w_fc*ones(1,11),cls,dbCD,lws,lw,lss,'--');
                hpw13m = plot(1:11,ds1034_w_mc*ones(1,11),cls,mbCD,lws,lw,lss,'--');
                legend([hpw11,hpw11m,hpw12,hpw12m,hpw13,hpw13m],...
                       {'water (gc)','k_{i} (gc)',...
                        'water (fc)','k_{i} (fc)',...
                        'water (mc)','k_{i} (mc)'},'location',locationstr)
                subplot 132
                hpw21 = plot(idx_w,ds1063.gc(idx_w),cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
                hpw22 = plot(idx_w,ds1063.fc(idx_w),cls,dbCD,lws,lw,lss,'none','Marker','d',mss,11);
                hpw23 = plot(idx_w,ds1063.mc(idx_w),cls,mbCD,lws,lw,lss,'none','Marker','o',mss,11);
                hpw21m = plot(1:11,ds1063_w_gc*ones(1,11),cls,lbCD,lws,lw,lss,'--');
                hpw22m = plot(1:11,ds1063_w_fc*ones(1,11),cls,dbCD,lws,lw,lss,'--');
                hpw23m = plot(1:11,ds1063_w_mc*ones(1,11),cls,mbCD,lws,lw,lss,'--');
                subplot 133
                hpw31 = plot(idx_w,ds1078.gc(idx_w),cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
                hpw32 = plot(idx_w,ds1078.fc(idx_w),cls,dbCD,lws,lw,lss,'none','Marker','d',mss,11);
                hpw33 = plot(idx_w,ds1078.mc(idx_w),cls,mbCD,lws,lw,lss,'none','Marker','o',mss,11);
                hpw31m = plot(1:11,ds1078_w_gc*ones(1,11),cls,lbCD,lws,lw,lss,'--');
                hpw32m = plot(1:11,ds1078_w_fc*ones(1,11),cls,dbCD,lws,lw,lss,'--');
                hpw33m = plot(1:11,ds1078_w_mc*ones(1,11),cls,mbCD,lws,lw,lss,'--');
                for ii=1:3
                    switch ii
                        case 1; hs1 = subplot(1,3,ii);
                        case 2; hs2 = subplot(1,3,ii);
                        case 3; hs3 = subplot(1,3,ii);
                    end
                    xlim([1 11]); xlabel('set');
                    ylim([-4 1]); 
                    set(gca,'XTick',1:11)
                    set(gca,'XTickLabel',{'1','','3','','5','','7','','9','','11'});
                    set(gca,'YTick',-4:1);
                    set(gca,'YTickLabel',{'','-3','-2','-1','0',''});
                    ylabel(['\Deltas(\nu_',num2str(ii),') [%]'])
                    grid on; box on;
                end
                set(hs1,'OuterPosition',[0, 0, 1/3, 1]);
                set(hs2,'OuterPosition',[1/3, 0, 1/3, 1]);
                set(hs3,'OuterPosition',[2/3, 0, 1/3, 1]);
                % adjust font size
                set(findobj(hf,fss,10),fss,fs)

                % export figure
                orient(hf,'landscape')
                set(hf,'PaperSize',[29.7 21/2])
                set(hf,'PaperPosition',[0 0 29.7 21/2])
                set(hf,'Renderer','painters')
                if bWindowOn==true
                    print(hf,'water','-djpeg','-r300');
                else
                    print(hf,'water_nw','-djpeg','-r300');
                end
                bPlotWater=false;
            end

            % analyzation of pure glucose/fructose
            hf = figure('color','white','visible',visibility);
            subplot 131
            hp1w = plot(zeros(18,1),ds1034_w,cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
            hp11 = plot(idx_c,ds1034_g,cls,lg,lws,lw,lss,'none','Marker','s',mss,11);
            hp12 = plot(idx_c,ds1034_f,cls,dg,lws,lw,lss,'none','Marker','s',mss,11);
            hpgf1 = plot(0:50,ds1034_g_fit,cls,lg,lws,lw);
            hpff1 = plot(0:50,ds1034_f_fit,cls,dg,lws,lw);
            legend([hp11,hpgf1,hp12,hpff1,hp1w],...
                   {'\rm glucose','$\varphi_i$','fructose','$\psi_i$','\rm water'},...
                   'location','NorthWest','interpreter','latex')
            subplot 132
            hp2w = plot(zeros(18,1),ds1063_w,cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
            hp21 = plot(idx_c,ds1063_g,cls,lg,lws,lw,lss,'none','Marker','s',mss,11);
            hp22 = plot(idx_c,ds1063_f,cls,dg,lws,lw,lss,'none','Marker','s',mss,11);
            hpgf2 = plot(0:50,ds1063_g_fit,cls,lg,lws,lw);
            hpff2 = plot(0:50,ds1063_f_fit,cls,dg,lws,lw);
            subplot 133
            hp3w = plot(zeros(18,1),ds1078_w,cls,lbCD,lws,lw,lss,'none','Marker','s',mss,11); hold on;
            hp31 = plot(idx_c,ds1078_g,cls,lg,lws,lw,lss,'none','Marker','s',mss,11);
            hp32 = plot(idx_c,ds1078_f,cls,dg,lws,lw,lss,'none','Marker','s',mss,11);
            hpgf3 = plot(0:50,ds1078_g_fit,cls,lg,lws,lw);
            hpff3 = plot(0:50,ds1078_f_fit,cls,dg,lws,lw);
            for ii=1:3
                switch ii
                    case 1; hs1 = subplot(1,3,ii);
                    case 2; hs2 = subplot(1,3,ii);
                    case 3; hs3 = subplot(1,3,ii);
                end
                set(gca,'XTick',0:5:50);
                set(gca,'YTick',-1:5);
                set(gca,'YTickLabel',{'','0','1','2','3','4','5'});
                set(gca,'XTickLabel',{'0','','10','','','25','','','','','50'});
                xlim([0 50]); xlabel('c [g/l]');
                ylim([-1 5]); 
                ylabel(['\Deltas(\nu_',num2str(ii),') [%]'])
                grid on; box on;
            end
            set(hs1,'OuterPosition',[0, 0, 1/3, 1]);
            set(hs2,'OuterPosition',[1/3, 0, 1/3, 1]);
            set(hs3,'OuterPosition',[2/3, 0, 1/3, 1]);

            % adjust font size
            set(findobj(hf,fss,10),fss,fs)

            % export figure
            orient(hf,'landscape')
            set(hf,'PaperSize',[29.7 21/2])
            set(hf,'PaperPosition',[0 0 29.7 21/2])
            set(hf,'Renderer','painters')
            if bWindowOn==true
                print(hf,['gf_ng',num2str(nFit_g),'_nf',num2str(nFit_f)],'-djpeg','-r300');
            else
                print(hf,['gf_nw_ng',num2str(nFit_g),'_nf',num2str(nFit_f)],'-djpeg','-r300');
            end

            % results for current nFit_g & nFit_f
            cg_gp = cg_g; cg_gp(find(cg_gp>=0 & cg_gp<=1)) = ones(size(find(cg_gp>=0 & cg_gp<=1)));
            cf_gp = cf_g; cf_gp(find(cf_gp>=0 & cf_gp<=1)) = ones(size(find(cf_gp>=0 & cf_gp<=1)));
            cg_fp = cg_f; cg_fp(find(cg_fp>=0 & cg_fp<=1)) = ones(size(find(cg_fp>=0 & cg_fp<=1)));
            cf_fp = cf_f; cf_fp(find(cf_fp>=0 & cf_fp<=1)) = ones(size(find(cf_fp>=0 & cf_fp<=1)));
            cg_mp = cg_m; cg_mp(find(cg_mp>=0 & cg_mp<=1)) = ones(size(find(cg_mp>=0 & cg_mp<=1)));
            cf_mp = cf_m; cf_mp(find(cf_mp>=0 & cf_mp<=1)) = ones(size(find(cf_mp>=0 & cf_mp<=1)));

            hf = figure('color','white','visible',visibility);

            barWidth     = 0.2; %0.25
            barOffset    = 0.2; %0.25
            txtOffsetLR  = 0.2; %0.25
            txtOffsetW   = -4;
            txtOffsetGF = 5;
        
            % glucose cycle (gc)
            subplot 131
            hbwg1 = bar((1:2:11)-barOffset,cg_gp(1:2:11),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD); hold on;
            hbwf1 = bar((1:2:11)+barOffset,cf_gp(1:2:11),barWidth,'FaceColor',dbCD,'EdgeColor',dbCD);
            hbg1  = bar((2:2:10)-barOffset,cg_gp(2:2:10),barWidth,'FaceColor',lg,'EdgeColor',lg);
            hbf1  = bar((2:2:10)+barOffset,cf_gp(2:2:10),barWidth,'FaceColor',dg,'EdgeColor',dg);
            for ii=1:2:11
                text(ii-txtOffsetLR,txtOffsetW,num2str(cg_g(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,txtOffsetW,num2str(cf_g(ii,1),'% 2.0f'),'Color',dbCD,'HorizontalAlignment','center');
            end
            for ii=2:2:10
                text(ii-txtOffsetLR,round(cg_gp(ii,1))+txtOffsetGF,num2str(cg_g(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,round(cf_gp(ii,1))+txtOffsetGF,num2str(cf_g(ii,1),'% 2.0f'),'Color',dg,'HorizontalAlignment','center');
            end

            % fructose cycle (fc)
            subplot 132
            hbwg2 = bar((1:2:11)-barOffset,cg_fp(1:2:11),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD); hold on;
            hbwf2 = bar((1:2:11)+barOffset,cf_fp(1:2:11),barWidth,'FaceColor',dbCD,'EdgeColor',dbCD);
            hbg2  = bar((2:2:10)-barOffset,cg_fp(2:2:10),barWidth,'FaceColor',lg,'EdgeColor',lg);
            hbf2  = bar((2:2:10)+barOffset,cf_fp(2:2:10),barWidth,'FaceColor',dg,'EdgeColor',dg);
            for ii=1:2:11
                text(ii-txtOffsetLR,txtOffsetW,num2str(cg_f(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,txtOffsetW,num2str(cf_f(ii,1),'% 2.0f'),'Color',dbCD,'HorizontalAlignment','center');
            end
            for ii=2:2:10
                text(ii-txtOffsetLR,round(cg_fp(ii,1))+txtOffsetGF,num2str(cg_f(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,round(cf_fp(ii,1))+txtOffsetGF,num2str(cf_f(ii,1),'% 2.0f'),'Color',dg,'HorizontalAlignment','center');
            end

            % mixed cycle (mc)
            subplot 133
            hbwg3 = bar((1:2:11)-barOffset,cg_mp(1:2:11),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD); hold on;
            hbwf3 = bar((1:2:11)+barOffset,cf_mp(1:2:11),barWidth,'FaceColor',dbCD,'EdgeColor',dbCD);
            hbg3  = bar((2:2:10)-barOffset,cg_mp(2:2:10),barWidth,'FaceColor',lg,'EdgeColor',lg);
            hbf3  = bar((2:2:10)+barOffset,cf_mp(2:2:10),barWidth,'FaceColor',dg,'EdgeColor',dg);
            for ii=1:2:11
                text(ii-txtOffsetLR,txtOffsetW,num2str(cg_m(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,txtOffsetW,num2str(cf_m(ii,1),'% 2.0f'),'Color',dbCD,'HorizontalAlignment','center');
            end
            for ii=2:2:10
                text(ii-txtOffsetLR,round(cg_mp(ii,1))+txtOffsetGF,num2str(cg_m(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
                text(ii+txtOffsetLR,round(cf_mp(ii,1))+txtOffsetGF,num2str(cf_m(ii,1),'% 2.0f'),'Color',dg,'HorizontalAlignment','center');
            end

            for ii=1:3
                switch ii
                    case 1; hs1 = subplot(1,3,ii);
                    case 2; hs2 = subplot(1,3,ii);
                    case 3; hs3 = subplot(1,3,ii);
                end
                set(gca,'XTick',1:11);
    %             set(gca,'XTickLabel',{});
                set(gca,'YTick',[0 10 20 30 40 50 60]);
                ylim([-10 70]); 
                xlim([0.25 11.75]);
                grid on; box on;
                ylabel('c [g/l]')
                switch ii
                    case 1;
                        hl = legend([hbg1 hbf1 hbwg1 hbwf1],...
                               {'glucose','fructose','water (g)','water (f)'},...
                               'location','northoutside',...
                               'orientation','horizontal',fss,fs_legend);
                        set(hl,'visible','Off');
                        xlabel('glucose cycle');
                    case 2;
                        hl = legend([hbg2 hbf2 hbwg2 hbwf2],...
                               {'glucose','fructose','water (g)','water (f)'},...
                               'location','northoutside',...
                               'orientation','horizontal',fss,fs_legend);
                        set(hl,'visible','Off');
                        xlabel('fructose cycle');
    %                     set(gca,'YTickLabel',{});
                    case 3;
                        hl = legend([hbg3 hbf3 hbwg3 hbwf3],...
                               {'glucose','fructose','water (g)','water (f)'},...
                               'location','northoutside',...
                               'orientation','horizontal',fss,fs_legend);
                        xlabel('mixed cycle');
    %                     set(gca,'YTickLabel',{});
                end
            end
        
            set(hs1,'OuterPosition',[0, 0, 1/3, 1]);
            set(hs2,'OuterPosition',[1/3, 0, 1/3, 1]);
            set(hs3,'OuterPosition',[2/3, 0, 1/3, 1]);

            % adjust font size
            set(findobj(hf,fss,10),fss,fs)

            % export figure
            orient(hf,'landscape')
            set(hf,'PaperSize',[29.7 21/2])
            set(hf,'PaperPosition',[0 0 29.7 21/2])
            set(hf,'Renderer','painters')
            if bWindowOn==true
                print(hf,['estim_c_ng',num2str(nFit_g),'_nf',num2str(nFit_f)],'-djpeg','-r300');
            else
                print(hf,['estim_c_nw_ng',num2str(nFit_g),'_nf',num2str(nFit_f)],'-djpeg','-r300');
            end
        end
    end
end

% export results to xlsx-file
file   = 'results_polyfit.xlsx';
if bWindowOn==true
    sheet = 'results_pp';       % results pre-processing
else
    sheet = 'results_pp_nw';    % results pre-processing with no window
end
idxSort = [1 4 7 2 5 8 3 6 9];
xlData = [[1 1 1 2 2 2 3 3 3]',...
          [1 2 3 1 2 3 1 2 3]',...
          err_rms(idxSort)',...
          err_avg(idxSort)',...
          err_max(idxSort)'];
xlRange = 'A2:E10';
[status,message] = xlswrite(file,xlData,sheet,xlRange);