%% Preprocess data
% Results are saved to results_alss_bc.xlsx
%
% Author:           Benjamin Schuler
% Company:          University of Stuttgart, Institute for System Dynamics
% Last modified:    21.02.2019 (Matlab 2015a)

clear; close all; clc;
cfroot = cd;

%% settings
load('plotStyleBS.mat');
fs        = 14;     % adjust font size
fs_legend = 13;     % font size in legend

%% load SEIRA-data
% idxCycle = 1 ... glucose cycle
% idxCycle = 2 ... fructose cycle
% idxCycle = 3 ... mixed cycle

for idxCycle=1:3
    switch idxCycle
        case 1;
            matFile = 'gc_data.mat';
            datasets = {'gc_1_c10_gl';'gc_1_water';...
                        'gc_2_c25_gl';'gc_2_water';...
                        'gc_3_c50_gl';'gc_3_water';...
                        'gc_4_c25_gl';'gc_4_water';...
                        'gc_5_c10_gl';'gc_5_water';...
                        'gc_6_water'};
        case 2;
            matFile = 'fc_data.mat';
            datasets = {'fc_1_c10_gl';'fc_1_water';...
                        'fc_2_c25_gl';'fc_2_water';...
                        'fc_3_c50_gl';'fc_3_water';...
                        'fc_4_c25_gl';'fc_4_water';...
                        'fc_5_c10_gl';'fc_5_water';...
                        'fc_6_water'};
        case 3;
            matFile = 'mc_data.mat';
            datasets = {'mc_1_G50_F0';'mc_1_water';...
                        'mc_2_F50_G0';'mc_2_water';...
                        'mc_3_F50_G50';'mc_3_water';...
                        'mc_4_30F_60G';'mc_4_water';...
                        'mc_5_F60_G30';'mc_5_water';...
                        'mc_6_water'};
    end
    load(matFile);

    for idxSet=1:length(datasets)

        % data set
        dataset = datasets{idxSet};
        eval(['x =',dataset,'.data1;']) 
        eval(['y =',dataset,'.data2;']) 

        % convert cell to array
        n = length(x{1});               % number of measurements
        m = length(x);                  % number of sampled data points
        x = reshape(cell2mat(x),n,m);   % wavenumbers [cm-1]
        y = reshape(cell2mat(y),n,m);   % rel. reflectance
          
        % mean value
        xc = mean(x,2);
        yc = mean(y,2);
        
        % variance and standard deviation
        V = var(y,0,2);
        S = std(y,0,2);
        
        % Zoomed area
        idxX = find(xc>=1000 & xc<=1100);
        Vz = mean(V(idxX));
        Sz = mean(S(idxX));
        
        % Visualisierung
        hf = figure('color','white','visible','off');
        
        hs1 = subplot(3,3,[1 2]);
        hp1 = plot(x,y,lws,lw,cls,lbCD);
        hold on;
        hp2 = plot(xc,yc,lws,lw,cls,dbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('r(\nu)');
        grid on; box on; 
        xlim([min(xc) max(xc)]);
        ylim([0 0.5])
        legend([hp1(1), hp2],{'data','mean(data)'},...
            'location','north',fss,fs_legend);
        title('(a)');
        
        hs2 = subplot(3,3,3);
        hp1 = plot(x,y,lws,lw,cls,lbCD);
        hold on;
        hp2 = plot(xc,yc,lws,2,cls,dbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('r(\nu)');
        grid on; box on; 
        xlim([1000 1100]);
        ylim([0.3 0.45]);
        legend([hp1(1), hp2],{'data','mean(data)'},...
            'location','best',fss,fs_legend);
        title('(b)');
        
        hs3 = subplot(3,3,[4 5]); 
        plot(xc,V,lws,lw,cls,lbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('var(r)');
        grid on; box on; 
        xlim([min(xc) max(xc)]);
        ylim([0 3]*1e-4);
        title('(c)');
        
        hs4 = subplot(3,3,6); 
        hp1 = plot(xc(idxX),V(idxX),lws,lw,cls,lbCD);
        hold on;
        hp2 = plot(xc(idxX),Vz*ones(size(idxX)),lws,lw,cls,dbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('var(r)');
        grid on; box on; 
        xlim([1000 1100]);
        ylim([0 12]*1e-6);
        title('(d)');
        legend([hp1, hp2],{'var','mean(var)'},...
            'location','best',fss,fs_legend);
        
        hs5 = subplot(3,3,[7 8]); 
        plot(xc,S,lws,lw,cls,lbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('std(r)');
        grid on; box on; 
        xlim([min(xc) max(xc)]);
        ylim([0 1.5]*1e-2);
        title('(e)');
        
        hs6 = subplot(3,3,9); 
        hp1 = plot(xc(idxX),S(idxX),lws,lw,cls,lbCD);
        hold on;
        hp2 = plot(xc(idxX),Sz*ones(size(idxX)),lws,lw,cls,dbCD);
        xlabel('\nu [cm^{-1}]'); ylabel('std(r)');
        grid on; box on; 
        xlim([1000 1100]);
        ylim([0 6]*1e-3);
        title('(f)');
        legend([hp1, hp2],{'var','mean(var)'},...
            'location','best',fss,fs_legend);
        
        set(hs1,'OuterPosition',[  0, 2/3, 2/3, 1/3]);
        set(hs2,'OuterPosition',[2/3, 2/3, 1/3, 1/3]);
        set(hs3,'OuterPosition',[  0, 1/3, 2/3, 1/3]);
        set(hs4,'OuterPosition',[2/3, 1/3, 1/3, 1/3]);
        set(hs5,'OuterPosition',[  0,   0, 2/3, 1/3]);
        set(hs6,'OuterPosition',[2/3,   0, 1/3, 1/3]);
        
        set(hs2,'YAxisLocation','right');
        set(hs4,'YAxisLocation','right');
        set(hs6,'YAxisLocation','right');
        
        % Adjust font size
        set(findobj(gcf,fss,10),fss,fs)
        
        % export figure
%         cd('..\02_Graphics')
        orient(hf,'landscape')
        set(hf,'PaperSize',[29.7 21*1.5])
        set(hf,'PaperPosition',[0 0 29.7 21*1.5])
        set(hf,'Renderer','painters')
        print(hf,['statistics_',num2str(idxCycle),'_',num2str(idxSet)],'-djpeg','-r300');
%         print(hf,'figure_3_paper','-dpdf', '-r300');
%         cd(cfroot)

%         % export results to xlsx-file
%         file   = 'results_statistics.xlsx';
%         sheet  = 'results_statistics';
%         xlData = [Vz,Sz];
%         switch idxCycle
%             case 1; idxOffset = 1;
%             case 2; idxOffset = 12;
%             case 3; idxOffset = 23;
%         end
%         xlRange = ['B',num2str(idxSet+idxOffset),...
%                    ':C',num2str(idxSet+idxOffset)];
%         [status,message] = xlswrite(file,xlData,sheet,xlRange);
%         disp(['data set: ',num2str(idxSet,'% 2.0f'),...
%               '   status xls: ',num2str(status)]);
    end
end

%% Import results
file   = 'results_statistics.xlsx';
sheet  = 'results_statistics';
data = xlsread(file,sheet,'B2:C34');

% re-order data
data = data([2,1,4,3,6,5,8,7,10,9,11,...
             13,12,15,14,17,16,19,18,21,20,22,...
             24,23,26,25,28,27,30,29,32,31,33],:);

% Plot settings
barWidth     = 0.45;
barWidth2    = 0.2;
barOffset    = 0.2;
txtOffsetW   = 5;
txtOffsetGF  = 4;
txtOffsetLR  = 0.2; %0.25

% Concentration levels (1 for water-vizualization)
cVec1 = [1,10,1,25,1,50,1,25,1,10,1]'; % for gc / fc
cVec2 = [1,50,1,0,1,50,1,60,1,30,1]';  % for mc (glucose)
cVec3 = [1,0,1,50,1,50,1,30,1,60,1]';  % for mc (fructose)

% Figure
hf = figure('color','white','visible','off');

% glucose cycle
hs(1) = subplot(3,3,1);
hb1 = bar(1:2:11,cVec1(1:2:11),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,cVec1(2:2:10),barWidth,'FaceColor',lg,'EdgeColor',lg);
hl1 = legend([hb1 hb2],{'water','glucose'},'location','north','orientation','horizontal',fss,fs_legend);
for ii=1:2:11
    text(ii,cVec1(ii,1)-txtOffsetW,num2str(cVec1(ii,1)-1,'% 2.0f'),'Color',mgrCD,'HorizontalAlignment','center');
end
for ii=2:2:10
    text(ii,cVec1(ii,1)+txtOffsetGF,num2str(cVec1(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
end

hs(4) = subplot(3,3,4);
hb1 = bar(1:2:11,data(1:2:11,1),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(2:2:11,1),barWidth,'FaceColor',lg,'EdgeColor',lg);
hl1 = legend([hb1 hb2],{'water','glucose'},'location','north','orientation','horizontal',fss,fs_legend);

hs(7) = subplot(3,3,7);
hb1 = bar(1:2:11,data(1:2:11,2),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(2:2:11,2),barWidth,'FaceColor',lg,'EdgeColor',lg);
hl1 = legend([hb1 hb2],{'water','glucose'},'location','north','orientation','horizontal',fss,fs_legend);


% fructose cycle
hs(2) = subplot(3,3,2);
hb1 = bar(1:2:11,cVec1(1:2:11),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,cVec1(2:2:10),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD);
hl2 = legend([hb1 hb2],{'water','fructose'},'location','north','orientation','horizontal',fss,fs_legend);
for ii=1:2:11
    text(ii,cVec1(ii,1)-txtOffsetW,num2str(cVec1(ii,1)-1,'% 2.0f'),'Color',mgrCD,'HorizontalAlignment','center');
end
for ii=2:2:10
    text(ii,cVec1(ii,1)+txtOffsetGF,num2str(cVec1(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
end

hs(5) = subplot(3,3,5);
hb1 = bar(1:2:11,data(12:2:22,1),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(13:2:22,1),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD);
hl1 = legend([hb1 hb2],{'water','fructose'},'location','north','orientation','horizontal',fss,fs_legend);

hs(8) = subplot(3,3,8);
hb1 = bar(1:2:11,data(12:2:22,2),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(13:2:22,2),barWidth,'FaceColor',lbCD,'EdgeColor',lbCD);
hl1 = legend([hb1 hb2],{'water','fructose'},'location','north','orientation','horizontal',fss,fs_legend);

% mixed cycle
hs(3) = subplot(3,3,3);
hb1 = bar((1:2:11),cVec2(1:2:11),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb3 = bar((2:2:10)-barOffset,[50,1,50,60,30],barWidth2,'FaceColor',lg,'EdgeColor',lg);
hb4 = bar((2:2:10)+barOffset,[1,50,50,30,60],barWidth2,'FaceColor',lbCD,'EdgeColor',lbCD);
for ii=1:2:11
    text(ii,cVec2(ii,1)-txtOffsetW,num2str(cVec3(ii,1)-1,'% 2.0f'),'Color',mgrCD,'HorizontalAlignment','center');
end
for ii=2:2:10
    if ii==6
        text(ii-barOffset,cVec2(ii,1)+txtOffsetGF*2,num2str(cVec2(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
        text(ii+barOffset,cVec3(ii,1)+txtOffsetGF,num2str(cVec3(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
    else
        text(ii-barOffset,cVec2(ii,1)+txtOffsetGF,num2str(cVec2(ii,1),'% 2.0f'),'Color',lg,'HorizontalAlignment','center');
        text(ii+barOffset,cVec3(ii,1)+txtOffsetGF,num2str(cVec3(ii,1),'% 2.0f'),'Color',lbCD,'HorizontalAlignment','center');
    end
end

hs(6) = subplot(3,3,6);
hb1 = bar(1:2:11,data(23:2:33,1),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(24:2:33,1),barWidth,'FaceColor',(lg+lbCD)/2,'EdgeColor',(lg+lbCD)/2);

hs(9) = subplot(3,3,9);
hb1 = bar(1:2:11,data(23:2:33,2),barWidth,'FaceColor',mgrCD,'EdgeColor',mgrCD); hold on;
hb2 = bar(2:2:10,data(24:2:33,2),barWidth,'FaceColor',(lg+lbCD)/2,'EdgeColor',(lg+lbCD)/2);

% Adjust subplots
for ii=1:9
    subplot(3,3,ii);
    set(gca,'XTick',1:11);
    xlim([0.25 11.75]);
%     set(gca,'XTickLabel',{});
    switch ii
        case 1
            set(gca,'YTick',[0 10 20 30 40 50 60]);
%             xlabel('glucose cycle');
            ylabel('c [g/l]');
            ylim([-10 70]); 
            title('(a)');
        case 2
            set(gca,'YTick',[0 10 20 30 40 50 60]);
%             xlabel('fructose cycle');
%             ylabel(' ');
            set(gca,'YTickLabel',{});
            ylim([-10 70]);
            title('(b)');
        case 3
            set(gca,'YTick',[0 10 20 30 40 50 60]);
%             xlabel('mixed cycle');
%             ylabel(' ');
            set(gca,'YTickLabel',{});
            ylim([-10 70]);
            title('(c)');
        case 4
            ylabel('mean(var(r)))');
            ylim([0 1]*1e-5); 
            title('(d)');
        case 5
            ylabel(' ');
            ylim([0 1]*1e-5); 
            set(gca,'YTickLabel',{});
            title('(e)');
        case 6
            ylabel(' ');
            ylim([0 1]*1e-5); 
            set(gca,'YTickLabel',{});
            title('(f)');
        case 7
            xlabel('glucose cycle');
            ylabel('mean(std(r)))');
            ylim([0 3]*1e-3); 
            title('(g)');
        case 8
            xlabel('fructose cycle');
            ylabel(' ');
            ylim([0 3]*1e-3); 
            set(gca,'YTickLabel',{});
            title('(h)');
        case 9
            xlabel('mixed cycle');
            ylabel(' ');
            ylim([0 3]*1e-3); 
            set(gca,'YTickLabel',{});
            title('(i)');
            
    end
    grid on; box on;
end

set(hs(1),'OuterPosition',[  0, 2/3, 1/3, 1/3]);
set(hs(2),'OuterPosition',[1/3, 2/3, 1/3, 1/3]);
set(hs(3),'OuterPosition',[2/3, 2/3, 1/3, 1/3]);
set(hs(4),'OuterPosition',[  0, 1/3, 1/3, 1/3]);
set(hs(5),'OuterPosition',[1/3, 1/3, 1/3, 1/3]);
set(hs(6),'OuterPosition',[2/3, 1/3, 1/3, 1/3]);
set(hs(7),'OuterPosition',[  0, 0,   1/3, 1/3]);
set(hs(8),'OuterPosition',[1/3, 0,   1/3, 1/3]);
set(hs(9),'OuterPosition',[2/3, 0,   1/3, 1/3]);

% Adjust font size
set(findobj(gcf,fss,10),fss,fs)

% export figure
% cd('..\02_Graphics')
orient(hf,'landscape')
set(hf,'PaperSize',[29.7 21*1.5])
set(hf,'PaperPosition',[0 0 29.7 21*1.5])
set(hf,'Renderer','painters')
print(hf,'statistics_analysis','-djpeg','-r300');
% print(hf,'figure_3_paper','-dpdf', '-r300');
% cd(cfroot)
